@@ -6,7 +6,7 @@ use 5.020;
 
 use parent 'Class::Accessor';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 Travel::Status::DE::DBRIS::Location->mk_ro_accessors(
 	qw(eva id lat lon name products type is_cancelled is_additional is_separation display_priority
@@ -21,11 +21,18 @@ sub new {
 
 	my $json = $opt{json};
 
+	# station search results include lat/lon keys in JSON; route entries do not
+	my ( $lon, $lat );
+	if ( $json->{id} =~ m{ [@]X= (?<lon> \d+) [@]Y= (?<lat> \d+) }x ) {
+		$lat = $+{lat} / 1e6;
+		$lon = $+{lon} / 1e6;
+	}
+
 	my $ref = {
 		eva            => $json->{extId} // $json->{evaNumber},
 		id             => $json->{id},
-		lat            => $json->{lat},
-		lon            => $json->{lon},
+		lat            => $json->{lat} // $lat,
+		lon            => $json->{lon} // $lon,
 		name           => $json->{name},
 		products       => $json->{products},
 		type           => $json->{type},
